@@ -43,7 +43,7 @@ class HardwareInfo:
 
         for k, v in dic.items():
             if k in ['cpu_id', 'cpu_name', 'arch_name', 'chip_name', 'vendor_name', 'board_name',
-                     'flash_program', 'toolchain_prefix', 'debug_server'] and v:
+                     'flash_program', 'toolchain_prefix', 'toolchain_path', 'debug_server'] and v:
                 self.__dict__[k] = v
             elif k in ['ld_script', 'icc_ld_script', 'armcc_ld_script'] and v:
                if (k == 'ld_script' and get_compiler() == 'gcc') or (k == 'icc_ld_script' and get_compiler() == 'icc') \
@@ -90,6 +90,7 @@ class HardwareInfo:
         self.program_data_files = []
         self.debug_server = ''
         self.toolchain_prefix = ''
+        self.toolchain_path = ''
 
         self.cpu_list = {}
 
@@ -169,7 +170,7 @@ class HardwareInfo:
                     for k, v in cpu.items():
                         text += '    {}: {}\n'.format(k, v)
         else:
-            for k in ['cpu_id', 'arch_name', 'vendor_name', 'chip_name', 'cpu_name', 'board_name', 'ld_script', 'toolchain_prefix']:
+            for k in ['cpu_id', 'arch_name', 'vendor_name', 'chip_name', 'cpu_name', 'board_name', 'ld_script', 'toolchain_prefix', 'toolchain_path']:
                 if self.__dict__[k]:
                     text += '  {}: {}\n'.format(k, self.__dict__[k])
 
@@ -190,6 +191,7 @@ class HardwareInfo:
 #   ld_script: configs/gcc_eflash.ld       # <可选项> 连接时使用 LD 脚本，当选把未设置时，使用对应的 board 的 LD 脚本
 #   flash_program: bin/flash_program.elf   # <可选项> 芯片全局烧写程序
 #   toolchain_prefix: csky-abiv2-elf       # <可选项> 编译器前缀
+#   toolchain_path: ''                     # <可选项> 用户自行配置的编译器路径
 #   cpu0:
 #     cpu_name: CK804EF                    # <必选项> 该芯片使用的 CPU 型号
 #     ld_script: configs/gcc_eflash.ld     # <必选项> 连接时使用 LD 脚本
@@ -220,6 +222,7 @@ class HardwareInfo:
 #   cpu_name: CK804EF
 #   ld_script: configs/gcc_eflash.ld
 #   toolchain_prefix: csky-abiv2-elf
+#   toolchain_path: 
 #   flash_program: bin/flash_program.elf
 
 ## chip component(多处理器)
