@@ -125,6 +125,7 @@ class Solution:
         self.ld_script_component = None
         self.cpu_name = ''
         self.toolchain_prefix = ''
+        self.toolchain_path = ''
         self.flash_program = ''
         self.program_data_files = []
         self.debug_server = ''
@@ -263,6 +264,20 @@ class Solution:
                     self.defines[k] = v
                     self.org_defines[k] = v
 
+        def check_duplicate_value(array, value):
+            check_num = 0
+            for c in array:
+                if( value != c ):
+                    check_num = check_num + 1;
+                else:
+                    check_num = 0;
+                    return True
+        
+            if(check_num == len(array)):
+                return False
+            else:
+                return True
+
         def update_variables():
             # copy defines
             for component in self.components:
@@ -304,32 +319,56 @@ class Solution:
                     solution_hw_info.merge(component.hw_info)
 
                     for c in component.build_config.cflag.split():
-                        self.CFLAGS.append(c)
+                        if(check_duplicate_value(self.CFLAGS, c) == False):
+                            self.CFLAGS.append(c)
+
                     for c in component.build_config.asmflag.split():
-                        self.ASFLAGS.append(c)
+                        if(check_duplicate_value(self.ASFLAGS, c) == False):
+                            self.ASFLAGS.append(c)
+
                     for c in component.build_config.cxxflag.split():
-                        self.CXXFLAGS.append(c)
+                        if(check_duplicate_value(self.CXXFLAGS, c) == False):
+                            self.CXXFLAGS.append(c)
+
                     for c in component.build_config.ldflag.split():
-                        self.LINKFLAGS.append(c)
+                        if(check_duplicate_value(self.LINKFLAGS, c) == False):
+                            self.LINKFLAGS.append(c)
+
                     for c in component.build_config.shldflag.split():
-                        self.SHLINKFLAGS.append(c)
+                        if(check_duplicate_value(self.SHLINKFLAGS, c) == False):
+                            self.SHLINKFLAGS.append(c)
+
                     for c in component.build_config.icc_cflag.split():
-                        self.ICC_CFLAGS.append(c)
+                        if(check_duplicate_value(self.ICC_CFLAGS, c) == False):
+                            self.ICC_CFLAGS.append(c)
+
                     for c in component.build_config.icc_asmflag.split():
-                        self.ICC_ASFLAGS.append(c)
+                        if(check_duplicate_value(self.ICC_ASFLAGS, c) == False):
+                            self.ICC_ASFLAGS.append(c)
+
                     for c in component.build_config.icc_cxxflag.split():
-                        self.ICC_CXXFLAGS.append(c)
+                        if(check_duplicate_value(self.ICC_CXXFLAGS, c) == False):
+                            self.ICC_CXXFLAGS.append(c)
+
                     for c in component.build_config.icc_ldflag.split():
-                        self.ICC_LINKFLAGS.append(c)
+                        if(check_duplicate_value(self.ICC_LINKFLAGS, c) == False):
+                            self.ICC_LINKFLAGS.append(c)
 
                     for c in component.build_config.armcc_cflag.split():
-                        self.ARMCC_CFLAGS.append(c)
+                        if(check_duplicate_value(self.ARMCC_CFLAGS, c) == False):
+                            self.ARMCC_CFLAGS.append(c)
+
                     for c in component.build_config.armcc_asmflag.split():
-                        self.ARMCC_ASFLAGS.append(c)
+                        if(check_duplicate_value(self.ARMCC_ASFLAGS, c) == False):
+                         self.ARMCC_ASFLAGS.append(c)
+
                     for c in component.build_config.armcc_cxxflag.split():
-                        self.ARMCC_CXXFLAGS.append(c)
+                        if(check_duplicate_value(self.ARMCC_CXXFLAGS, c) == False):
+                            self.ARMCC_CXXFLAGS.append(c)
+
                     for c in component.build_config.armcc_ldflag.split():
-                        self.ARMCC_LINKFLAGS.append(c)
+                        if(check_duplicate_value(self.ARMCC_LINKFLAGS, c) == False):
+                            self.ARMCC_LINKFLAGS.append(c)
 
             # 根据 cpu_id 加载配置
             if solution_hw_info.cpu_id in solution_hw_info.cpu_list:
@@ -420,6 +459,7 @@ class Solution:
                         self.libs.append(lib)
 
             self.toolchain_prefix = solution_hw_info.toolchain_prefix
+            self.toolchain_path = solution_hw_info.toolchain_path
             self.ld_script = solution_hw_info.ld_script
             self.ld_script = self.variables.convert(self.ld_script)
 
@@ -528,6 +568,7 @@ class Solution:
             put_string("SHLINKFLAGS :" + ' '.join(self.SHLINKFLAGS))
             put_string('ld_script : ' + self.ld_script)
             put_string('toolchain : ' + self.toolchain_prefix)
+            put_string('toolchain_path :' + self.toolchain_path)
             # put_string("\nIAR COMPILER")
             # put_string("ASFLAGS   :" + ' '.join(self.ICC_ASFLAGS))
             # put_string("CFLAGS   :" + ' '.join(self.ICC_CFLAGS))
@@ -575,6 +616,8 @@ def riscv_cpu_id(cpu):
         return 'rv64_32gpr'
     elif a == 'c906fd' or a == 'c906v' or a == 'c910' or a == 'c910v' or a == 'c906fdv':
         return 'rv64fd_32gpr'
+    elif a == 'esp32-c3':
+        return 'rv32imc'
     else:
         put_string("%s not support yet." % a)
         exit(0)
