@@ -23,7 +23,8 @@ all_toolchain_url = {
     'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-win32.git -b aos',
     'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-windows.git',
     'riscv64-ali-aos': 'https://gitee.com/alios-things/gcc-riscv-ali-aos-windows.git',
-    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-win64.tar.bz2'
+    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-win64.tar.bz2',
+    'riscv32-esp-elf': 'https://hli.aliyuncs.com/p/config/esp32_toolchain/riscv32-esp-elf-gcc8_4_0-esp-2021r2-patch2-win64.zip'
     }, 
     'Linux32':{
     'csky-abiv2-elf': 'http://yoctools.oss-cn-beijing.aliyuncs.com/csky-elfabiv2-tools-i386-minilibc-20200407.tar.gz',
@@ -37,7 +38,8 @@ all_toolchain_url = {
     'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-linux.git -b aos',
     'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-linux.git',
     'riscv64-ali-aos': 'https://gitee.com/alios-things/gcc-riscv-ali-aos-linux.git',
-    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-linux-amd64.tar.gz'
+    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-linux-amd64.tar.gz',
+    'riscv32-esp-elf': 'https://hli.aliyuncs.com/p/config/esp32_toolchain/riscv32-esp-elf-gcc8_4_0-esp-2021r2-linux-amd64.tar.gz'
     }, 
     'OSX':{
     'csky-abiv2-elf': '',
@@ -45,7 +47,8 @@ all_toolchain_url = {
     'arm-none-eabi': 'https://gitee.com/alios-things/gcc-arm-none-eabi-osx.git -b aos',
     'arm-ali-aoseabi': 'https://gitee.com/alios-things/gcc-arm-ali-aoseabi-osx.git',
     'riscv64-ali-aos': 'https://gitee.com/alios-things/gcc-riscv-ali-aos-osx.git',
-    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-macos.tar.gz'
+    'xtensa-esp32-elf': 'https://hli.aliyuncs.com/o/config/esp32_toolchain/xtensa-esp32-elf-gcc8_4_0-esp-2020r3-macos.tar.gz',
+    'riscv32-esp-elf': 'https://hli.aliyuncs.com/p/config/esp32_toolchain/riscv32-esp-elf-gcc8_4_0-esp-2021r2-macos.tar.gz'
     }
 }
 
@@ -91,13 +94,13 @@ class ToolchainYoC:
             put_string("Start install, wait half a minute please.")
             if tar_path.endswith('.bz2'):
                 with tarfile.open(tar_path, 'r:bz2') as tar:
-                    if(arch == 'xtensa-esp32-elf'):
+                    if(arch == 'xtensa-esp32-elf') or (arch == 'riscv32-esp-elf'):
                         tar.extractall(self.basepath)
                     else:
                         tar.extractall(toolchain_path)
             elif tar_path.endswith('.gz'):
                 with tarfile.open(tar_path, 'r:gz') as tar:
-                    if(arch == 'xtensa-esp32-elf'):
+                    if(arch == 'xtensa-esp32-elf') or (arch == 'riscv32-esp-elf'):
                         tar.extractall(self.basepath)
                     else:
                         tar.extractall(toolchain_path)
@@ -111,16 +114,43 @@ class ToolchainYoC:
         put_string(tar_path)
         put_string("Congratulations!")
 
-    def check_toolchain(self, arch='csky-abiv2-elf', verbose=0):
-        bin_file = self.check_program(arch)
+    def check_toolchain(self, arch='csky-abiv2-elf', path = '', verbose=0):
+        bin_file = ''
+        # first check user settings arch path
+        if path:
+            bin_file = self.check_toolchain_by_path(arch, path)
+            if not bin_file:
+                print('user setting toolchain path is abnormal')
+
         if not bin_file:
-            self.download(arch)
             bin_file = self.check_program(arch)
+            if not bin_file:
+                self.download(arch)
+                bin_file = self.check_program(arch)
+            else:
+                if verbose == 1:
+                    put_string('warn: the toolchains was installed already, path = %s.' % bin_file)
         else:
-            if verbose == 1:
-                put_string('warn: the toolchains was installed already, path = %s.' % bin_file)
+            print('use user settings toolchain path!!')
+
         return bin_file
 
+    def check_toolchain_by_path(self, arch='csky-abiv2-elf', tool_path=''):
+        path = ""
+        if not path:
+            path = os.path.join(tool_path, "bin", arch + '-gcc')
+            path = which(path)
+            if not path:
+                path = os.path.join(tool_path, "main", "bin", arch + '-gcc')
+                path = which(path)
+                if not path:
+                    path = os.path.join(tool_path, arch, "bin", arch + '-gcc')
+                    path = which(path)
+                    if not path:
+                        path = os.path.join(tool_path, arch, "main", "bin", arch + '-gcc')
+                        path = which(path)
+        return path
+
     def check_program(self, arch='csky-abiv2-elf'):
         """ check PATH, ~/.aliot/<arch>/bin,  ~/.aliot/<arch>/main/bin"""
         path = which(arch + '-gcc')
@@ -136,6 +166,9 @@ class ToolchainYoC:
         if arch.startswith('xtensa-esp32-elf'):
             # xtensa-esp32-elf toolchain updated!
             path = ""
+        if arch.startswith('riscv32-esp-elf'):
+            # riscv32-esp-elf toolchain updated!
+            path = ""
 
         if not path:
             path = os.path.join(self.basepath, arch, "bin", arch + '-gcc')
@@ -143,6 +176,13 @@ class ToolchainYoC:
             if not path:
                 path = os.path.join(self.basepath, arch, "main", "bin", arch + '-gcc')
                 path = which(path)
+                if not path:
+                    path = os.path.join(self.basepath, arch, arch, "bin", arch + '-gcc')
+                    path = which(path)
+                    if not path:
+                        path = os.path.join(self.basepath, arch, arch, "main", "bin", arch + '-gcc')
+                        path = which(path)
+
         return path
 
     def uninstall_toolchain(self, arch='csky-abiv2-elf'):
@@ -159,6 +199,9 @@ class ToolchainYoC:
         if arch.startswith('xtensa-esp32-elf'):
             # xtensa-esp32-elf toolchain updated!
             path = ""
+        if arch.startswith('riscv32-esp32-elf'):
+            # riscv32-esp32-elf toolchain updated!
+            path = ""
 
         if not path:
             path = os.path.join(self.basepath, arch, "bin", arch + '-gcc')
